InstallStateAndroid class

Represents the current install state during a flexible update on Android.

Emitted by InAppUpdateFlutter.installStateStreamAndroid.

Constructors

InstallStateAndroid({required InstallStatusAndroid status, required int bytesDownloaded, required int totalBytesToDownload})
const
InstallStateAndroid.fromMap(Map<String, dynamic> map)
Creates an InstallStateAndroid from a map received via the event channel.
factory

Properties

bytesDownloaded int
The number of bytes downloaded so far.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status InstallStatusAndroid
The current install status.
final
totalBytesToDownload int
The total number of bytes to download.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited