InstallStatusAndroid enum

Represents the install status of an in-app update on Android.

Maps directly to Play Core's InstallStatus constants.

Inheritance
Available extensions

Values

unknown → const InstallStatusAndroid

Install status is unknown.

pending → const InstallStatusAndroid

The update is pending and will be downloaded soon.

downloading → const InstallStatusAndroid

The update is currently being downloaded.

downloaded → const InstallStatusAndroid

The update has been downloaded and is ready to be installed.

installing → const InstallStatusAndroid

The update is currently being installed.

installed → const InstallStatusAndroid

The update has been installed successfully.

failed → const InstallStatusAndroid

The update has failed.

canceled → const InstallStatusAndroid

The update has been canceled by the user.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromPlayCoreValue(int value) InstallStatusAndroid
Creates an InstallStatusAndroid from a Play Core integer value.

Constants

values → const List<InstallStatusAndroid>
A constant List of the values in this enum, in order of their declaration.