UpdateAvailabilityAndroid enum
Represents the availability of an in-app update on Android.
Maps directly to Play Core's UpdateAvailability constants.
Values
- unknown → const UpdateAvailabilityAndroid
-
Update availability is unknown.
- updateNotAvailable → const UpdateAvailabilityAndroid
-
No update is available.
- updateAvailable → const UpdateAvailabilityAndroid
-
An update is available.
- developerTriggeredUpdateInProgress → const UpdateAvailabilityAndroid
-
An update has been previously started by the developer and is still in progress.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPlayCoreValue(
int value) → UpdateAvailabilityAndroid - Creates an UpdateAvailabilityAndroid from a Play Core integer value.
Constants
-
values
→ const List<
UpdateAvailabilityAndroid> - A constant List of the values in this enum, in order of their declaration.