UpdateResultAndroid enum

Represents the result of an in-app update flow on Android.

Inheritance
Available extensions

Values

success → const UpdateResultAndroid

The update was accepted and completed successfully.

userCanceled → const UpdateResultAndroid

The user canceled the update.

inAppUpdateFailed → const UpdateResultAndroid

The update flow failed due to an error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) UpdateResultAndroid
Creates an UpdateResultAndroid from an integer value.

Constants

values → const List<UpdateResultAndroid>
A constant List of the values in this enum, in order of their declaration.