AppUpdateInfoAndroid class
Contains information about an available in-app update on Android.
Returned by InAppUpdateFlutter.checkUpdateAndroid.
Constructors
- AppUpdateInfoAndroid({required UpdateAvailabilityAndroid updateAvailability, int? availableVersionCode, required int updatePriority, int? clientVersionStalenessDays, required bool isImmediateUpdateAllowed, required bool isFlexibleUpdateAllowed, required InstallStatusAndroid installStatus})
-
const
-
AppUpdateInfoAndroid.fromMap(Map<
String, dynamic> map) -
Creates an AppUpdateInfoAndroid from a map received via the method channel.
factory
Properties
- availableVersionCode → int?
-
The version code of the available update, or
nullif unavailable.final - clientVersionStalenessDays → int?
-
The number of days since the update became available on the Play Store,
or
nullif unavailable.final - hashCode → int
-
The hash code for this object.
no setterinherited
- installStatus → InstallStatusAndroid
-
The current install status of the update.
final
- isFlexibleUpdateAllowed → bool
-
Whether a flexible update is allowed for this update.
final
- isImmediateUpdateAllowed → bool
-
Whether an immediate update is allowed for this update.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateAvailability → UpdateAvailabilityAndroid
-
The availability of an update.
final
- updatePriority → int
-
The in-app update priority as set by the developer in the
Google Play Developer API. Ranges from 0 (default) to 5 (highest).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited